@@ -122,7 +122,7 @@ class DataSet(
             'set_parents()', 'set_children()', 'set_components()', 'set_contained()', 'set_containers()',
             'set_tags()', 'add_tags()', 'del_tags()',
             'add_attachment()', 'get_attachments()', 'download_attachments()',
-            "get_files()", 'file_list', 'file_links', 'physicalData',
+            "get_files()", 'file_list', 'file_links', 'rel_file_links', 'physicalData',
             'download()','download_path', 'is_physical()', 'symlink()', 'is_symlink()',
             'archive()', 'unarchive()',
             'save()', 'delete()', 'mark_to_be_deleted()', 'unmark_to_be_deleted()', 'is_marked_to_be_deleted()',
@@ -505,8 +505,8 @@ class DataSet(
 
     @property
     def file_list(self):
-        """returns the list of files including their directories as an array of strings. Just folders are not
-        listed.
+        """Returns the list of files including their directories as an array of strings.
+        Folders are not listed.
         """
 
         if self.is_new:
@@ -522,6 +522,10 @@ class DataSet(
         
     @property
     def file_links(self):
+        """Returns a dictionary of absolute file links for every file in this dataSet.
+        As the link also contains a session token (sessionID), sharing this link might be
+        a security risk. When the token is no longer valid, the link will no longer work either.
+        """
         if self.is_new:
             return ''
         url = self.openbis.url
@@ -536,6 +540,23 @@ class DataSet(
                     
         return file_links
 
+    @property
+    def rel_file_links(self):
+        """Returns a dictionary of relative file links for every file in this dataSet. These relative file link can be embedded in a <img src="{rel_link}">
+        element within a XML property. If the dataSet file happens to be a picture, in ELN-LIMS, the picture will be displayed inline.
+        """
+        if self.is_new:
+            return ''
+        url = self.openbis.url
+        location_part = self.physicalData.location.split('/')[-1] 
+        
+        rel_file_links = {}
+        for filepath in self.file_list:
+            quoted_filepath = urllib.parse.quote(filepath, safe='')
+            rel_file_links[filepath] = '/'.join(['/datastore_server', location_part, quoted_filepath])
+                    
+        return rel_file_links
+
     def get_files(self, start_folder='/'):
         """Returns a DataFrame of all files in this dataset
         """
